==> test-envelope-ui-0.0.32.tgz: package/es/grid/grid.js <==
var _templateObject = _taggedTemplateLiteralLoose(['\n  &&& {\n    box-sizing: border-box;\n    align-content: ', ';\n    align-items: ', ';\n  }\n'], ['\n  &&& {\n    box-sizing: border-box;\n    align-content: ', ';\n    align-items: ', ';\n  }\n']);

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _taggedTemplateLiteralLoose(strings, raw) { strings.raw = raw; return strings; }

import React, { useEffect } from 'react';
import styled from 'styled-components';
import PropTypes from 'prop-types';

var propTypes = {
  /** Determines flex position */
  align: PropTypes.oneOf(['center', 'end', 'start', 'stretch'])
};

var defaultProps = {
  align: 'center'
};

var StyledGrid = styled.div(_templateObject, function (props) {
  return (props.align === 'start' || props.align === 'end' ? 'flex-' : '') + props.align;
}, function (props) {
  return (props.align === 'start' || props.align === 'end' ? 'flex-' : '') + props.align;
});

/**
 * The `Grid` component...
 */
var Grid = function Grid(_ref) {
  var loading = _ref.loading,
      children = _ref.children,
      props = _objectWithoutProperties(_ref, ['loading', 'children']);

  return React.createElement(
    React.Fragment,
    null,
    React.createElement(
      StyledGrid,
      props,
      loading ? children : React.createElement(
        React.Fragment,
        null,
        children
      )
    )
  );
};

Grid.propTypes = process.env.NODE_ENV !== "production" ? propTypes : {};
Grid.defaultProps = defaultProps;

export default Grid;

==> test-envelope-ui-0.0.40.tgz: package/es/grid/grid.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _templateObject = _taggedTemplateLiteralLoose(['\n  &&& {\n    box-sizing: border-box;\n    align-content: ', ';\n    align-items: ', ';\n  }\n'], ['\n  &&& {\n    box-sizing: border-box;\n    align-content: ', ';\n    align-items: ', ';\n  }\n']);

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _taggedTemplateLiteralLoose(strings, raw) { strings.raw = raw; return strings; }

import React, { useEffect } from 'react';
import styled, { ThemeContext } from 'styled-components';
import PropTypes from 'prop-types';

import { clutchd, themeProps } from '../style/themes';
import { getTheme } from '../style/utils';

var propTypes = {
  theme: themeProps,
  /** Determines flex position */
  align: PropTypes.oneOf(['center', 'end', 'start', 'stretch'])
};

var defaultProps = {
  theme: clutchd,
  align: 'center'
};

var StyledGrid = styled.div(_templateObject, function (props) {
  return (props.align === 'start' || props.align === 'end' ? 'flex-' : '') + props.align;
}, function (props) {
  return (props.align === 'start' || props.align === 'end' ? 'flex-' : '') + props.align;
});

/**
 * The `Grid` component...
 */
var Grid = function Grid(_ref) {
  var theme = _ref.theme,
      loading = _ref.loading,
      children = _ref.children,
      props = _objectWithoutProperties(_ref, ['theme', 'loading', 'children']);

  var currentTheme = getTheme(ThemeContext, theme);

  return React.createElement(
    React.Fragment,
    null,
    React.createElement(
      StyledGrid,
      _extends({ theme: currentTheme }, props),
      loading ? children : React.createElement(
        React.Fragment,
        null,
        children
      )
    )
  );
};

Grid.propTypes = process.env.NODE_ENV !== "production" ? propTypes : {};
Grid.defaultProps = defaultProps;

export default Grid;
